==> sources_fancymenu_fabric_3.8.0_MC_1.19.2.jar: de/keksuccino/fancymenu/customization/placeholder/AsyncPlaceholderErrorScreen.java <==
package de.keksuccino.fancymenu.customization.placeholder;

import com.mojang.blaze3d.systems.RenderSystem;
import de.keksuccino.fancymenu.util.rendering.gui.GuiGraphics;
import de.keksuccino.fancymenu.util.rendering.ui.UIBase;
import de.keksuccino.fancymenu.util.rendering.ui.screen.queueable.QueueableScreen;
import de.keksuccino.fancymenu.util.rendering.ui.widget.button.ExtendedButton;
import org.jetbrains.annotations.NotNull;
import java.util.List;
import net.minecraft.class_2561;
import net.minecraft.class_2583;
import net.minecraft.class_5481;

public class AsyncPlaceholderErrorScreen extends QueueableScreen {

    @NotNull
    protected class_2561 placeholderName;
    protected List<class_5481> renderText;

    protected AsyncPlaceholderErrorScreen(@NotNull class_2561 placeholderName) {
        super(class_2561.method_43473());
        this.placeholderName = placeholderName.method_27661().method_27696(class_2583.field_24360.method_10982(true).method_36139(UIBase.getUIColorTheme().error_text_color.getColorInt()));
    }

    @Override
    protected void method_25426() {

        int centerX = this.field_22789 / 2;

        super.method_25426();

        this.renderText = this.field_22793.method_1728(class_2561.method_43469("fancymenu.placeholders.async.cant_run_async", this.placeholderName), this.field_22789 - 60);

        UIBase.applyDefaultWidgetSkinTo(this.method_37063(new ExtendedButton(centerX - 100, this.field_22790 - 50, 200, 20, class_2561.method_43471("fancymenu.common_components.ok"), button -> {
            this.method_25419();
        })));

    }

    @Override
    public void render(@NotNull GuiGraphics graphics, int mouseX, int mouseY, float partial) {

        this.renderBackground(graphics);

        super.render(graphics, mouseX, mouseY, partial);

        int centerX = this.field_22789 / 2;
        int centerY = this.field_22790 / 2;

        if (this.renderText == null) return;

        // Calculate the total height of all text lines
        int lineHeight = this.field_22793.field_2000 + 2; // Add 2 pixels of spacing between lines
        int totalTextHeight = this.renderText.size() * lineHeight;
        
        // Start rendering from the top of the centered text block
        int renderY = centerY - (totalTextHeight / 2);
        
        for (class_5481 s : this.renderText) {
            graphics.drawCenteredString(this.field_22793, s, centerX, renderY, UIBase.getUIColorTheme().generic_text_base_color.getColorInt());
            renderY += lineHeight;
        }

    }

    @Override
    public void renderBackground(@NotNull GuiGraphics graphics) {
        RenderSystem.enableBlend();
        graphics.fill(0, 0, this.field_22789, this.field_22790, UIBase.getUIColorTheme().screen_background_color.getColorInt());
    }

}

==> sources_fancymenu_fabric_3.8.1_MC_1.21.10.jar: de/keksuccino/fancymenu/customization/placeholder/AsyncPlaceholderErrorScreen.java <==
package de.keksuccino.fancymenu.customization.placeholder;

import com.mojang.blaze3d.systems.RenderSystem;
import de.keksuccino.fancymenu.util.rendering.ui.UIBase;
import de.keksuccino.fancymenu.util.rendering.ui.screen.queueable.QueueableScreen;
import de.keksuccino.fancymenu.util.rendering.ui.widget.button.ExtendedButton;
import org.jetbrains.annotations.NotNull;
import java.util.List;
import net.minecraft.class_2561;
import net.minecraft.class_2583;
import net.minecraft.class_332;
import net.minecraft.class_5481;

public class AsyncPlaceholderErrorScreen extends QueueableScreen {

    @NotNull
    protected class_2561 placeholderName;
    protected List<class_5481> renderText;

    protected AsyncPlaceholderErrorScreen(@NotNull class_2561 placeholderName) {
        super(class_2561.method_43473());
        this.placeholderName = placeholderName.method_27661().method_27696(class_2583.field_24360.method_10982(true).method_36139(UIBase.getUIColorTheme().error_text_color.getColorInt()));
    }

    @Override
    protected void method_25426() {

        int centerX = this.field_22789 / 2;

        super.method_25426();

        this.renderText = this.field_22793.method_1728(class_2561.method_43469("fancymenu.placeholders.async.cant_run_async", this.placeholderName), this.field_22789 - 60);

        UIBase.applyDefaultWidgetSkinTo(this.method_37063(new ExtendedButton(centerX - 100, this.field_22790 - 50, 200, 20, class_2561.method_43471("fancymenu.common_components.ok"), button -> {
            this.method_25419();
        })));

    }

    @Override
    public void method_25394(@NotNull class_332 graphics, int mouseX, int mouseY, float partial) {

        super.method_25394(graphics, mouseX, mouseY, partial);

        int centerX = this.field_22789 / 2;
        int centerY = this.field_22790 / 2;

        if (this.renderText == null) return;

        // Calculate the total height of all text lines
        int lineHeight = this.field_22793.field_2000 + 2; // Add 2 pixels of spacing between lines
        int totalTextHeight = this.renderText.size() * lineHeight;
        
        // Start rendering from the top of the centered text block
        int renderY = centerY - (totalTextHeight / 2);
        
        for (class_5481 s : this.renderText) {
            graphics.method_35719(this.field_22793, s, centerX, renderY, UIBase.getUIColorTheme().generic_text_base_color.getColorInt());
            renderY += lineHeight;
        }

    }

    @Override
    public void method_25420(@NotNull class_332 graphics, int $$1, int $$2, float $$3) {
        graphics.method_25294(0, 0, this.field_22789, this.field_22790, UIBase.getUIColorTheme().screen_background_color.getColorInt());
    }

}
